@@ -1,6 +1,6 @@
 ####### Special object
 
-class Person:
+class Person(object):
 	def __init__(self, name, age):
 		self.name=name
 		self.age=age
